pub struct IotaEnv { /* private fields */ }Expand description
IOTA environment configuration, containing the RPC URL, and optional websocket, basic auth and faucet options.
Implementations
Sourceimpl IotaEnv
impl IotaEnv
pub fn alias(&self) -> &String
pub fn rpc(&self) -> &String
pub fn graphql(&self) -> &Option<String>
pub fn ws(&self) -> &Option<String>
Sourcepub fn basic_auth(&self) -> &Option<String>
pub fn basic_auth(&self) -> &Option<String>
Basic HTTP access authentication in the format of username:password, if needed.
pub fn faucet(&self) -> &Option<String>
Sourceimpl IotaEnv
impl IotaEnv
pub fn alias_mut(&mut self) -> &mut String
pub fn rpc_mut(&mut self) -> &mut String
pub fn graphql_mut(&mut self) -> &mut Option<String>
pub fn ws_mut(&mut self) -> &mut Option<String>
Sourcepub fn basic_auth_mut(&mut self) -> &mut Option<String>
pub fn basic_auth_mut(&mut self) -> &mut Option<String>
Basic HTTP access authentication in the format of username:password, if needed.
pub fn faucet_mut(&mut self) -> &mut Option<String>
Sourceimpl IotaEnv
impl IotaEnv
Sourcepub fn new(alias: impl Into<String>, rpc: impl Into<String>) -> Self
pub fn new(alias: impl Into<String>, rpc: impl Into<String>) -> Self
Create a new IotaEnv with the given alias and RPC URL such as https://api.testnet.iota.cafe.
Sourcepub fn with_graphql(self, graphql: impl Into<Option<String>>) -> Self
pub fn with_graphql(self, graphql: impl Into<Option<String>>) -> Self
Set a graphql URL.
Sourcepub fn set_graphql(&mut self, graphql: impl Into<Option<String>>)
pub fn set_graphql(&mut self, graphql: impl Into<Option<String>>)
Set a graphql URL.
Sourcepub fn with_basic_auth(self, basic_auth: impl Into<Option<String>>) -> Self
pub fn with_basic_auth(self, basic_auth: impl Into<Option<String>>) -> Self
Set basic authentication information in the format of username:password.
Sourcepub fn set_basic_auth(&mut self, basic_auth: impl Into<Option<String>>)
pub fn set_basic_auth(&mut self, basic_auth: impl Into<Option<String>>)
Set basic authentication information in the format of username:password.
Sourcepub fn with_faucet(self, faucet: impl Into<Option<String>>) -> Self
pub fn with_faucet(self, faucet: impl Into<Option<String>>) -> Self
Set a faucet URL such as https://faucet.testnet.iota.cafe/v1/gas.
Sourcepub fn set_faucet(&mut self, faucet: impl Into<Option<String>>)
pub fn set_faucet(&mut self, faucet: impl Into<Option<String>>)
Set a faucet URL such as https://faucet.testnet.iota.cafe/v1/gas.
Sourcepub async fn create_rpc_client(
&self,
request_timeout: impl Into<Option<Duration>>,
max_concurrent_requests: impl Into<Option<u64>>,
) -> Result<IotaClient, Error>
pub async fn create_rpc_client( &self, request_timeout: impl Into<Option<Duration>>, max_concurrent_requests: impl Into<Option<u64>>, ) -> Result<IotaClient, Error>
Create an IotaClient with the given request timeout, max
concurrent requests and possible configured websocket URL and basic
auth.